#!/bin/sh

###############################################################################
#      A Generalized PP States Script for AF Transition Metal Monoxides       #
#                            P. M. Grant                                      #
#                          February, 2008                                     #
###############################################################################

###############################################################################
#    Element and Structure-Specific Constants & Data (Meant To Be Edited)     #
#                              (!con cuidado!)                                #
#           Change Log:                                                       #
#              03/27/11 - Option for QE-4.2.1                                 #
#                                                                             #
###############################################################################
TM='Cu';	A='O'
#TM='Ni';	A='O'
#TM='Fe';	A='O'
prefix=af-$TM$A
###############################################################################
# Housekeeping and Various Setup Stuff                                        #
###############################################################################
now=`date`
cd `echo $0 | sed 's/\(.*\)\/.*/\1/'`
home_dir=`pwd`
#pwscf_distro='espresso-3.2.3'
#pwscf_distro='espresso4.0cvs'
#pwscf_distro='O-sesame'
pwscf_distro='espresso-4.2.1'
dos_exec='/home/pmpgrant/'$pwscf_distro'/PP/dos.x'
projwfc_exec='/home/pmpgrant/'$pwscf_distro'/PP/projwfc.x'
# cat to $prefix.states.data file
printf "$0 \n" > $prefix.states.data
cat >> $prefix.states.data << EOF
  A PWscf script to calculate the dos and projected wfc properties of $prefix
  Starting at $now
*******************************************************************************
Element, Structure and Run Parameter Editable Options (!con cuidado!)
---------------------------------------------------------------------
  TM = $TM		A = $A
  
*******************************************************************************
Housekeeping
------------
  PWscf Distro = $pwscf_distro
  My Home      = $home_dir
  dos Exec     = $dos_exec
  projwfc Exec = $projwfc_exec
EOF

###############################################################################
# Generate State Plot Input                                                   #
###############################################################################
cat > $prefix.dos.in << EOF
 &inputpp
  prefix		= '$prefix',
  outdir		= '$home_dir',
  fildos		= '$prefix.dos',
  DeltaE 		= 0.1,
 /
EOF
cat > $prefix.pdos.in << EOF
 &inputpp
  prefix		= '$prefix',
  outdir		= '$home_dir',
  DeltaE		= 0.1,
  filpdos		= '$prefix',
 /
EOF

###############################################################################
# Do States Calcs & Plots                                                     #
###############################################################################
cat >> $prefix.states.data << EOF

*******************************************************************************
Listing Input Files...
DOS
EOF
cat $prefix.dos.in >> $prefix.states.data
cat >> $prefix.states.data << EOF
PDOS
EOF
cat $prefix.pdos.in >> $prefix.states.data
cat >> $prefix.states.data << EOF
Beginning States Calculations...
Starting at `date`
EOF
$dos_exec < $prefix.dos.in | tee $prefix.dos.out
$projwfc_exec < $prefix.pdos.in | tee $prefix.pdos.out
cat >> $prefix.states.data << EOF
Finished at `date`
EOF



