#!/bin/sh

###############################################################################
#  Generalized Electron-Phonon ph.x Script for NM YBCO or RE-BCO Structures   #
#                             P. M. Grant                                     #
#                            December, 2010                                   #
###############################################################################

###############################################################################
#    Element and Structure-Specific Constants & Data (Meant To Be Edited)     #
#                              (!con cuidado!)                                #
#                                                                             #
#           Change Log:                                                       #
#              12/05/10 - e-p coupling                                        # 
#              12/25/10 - change elph flag to .false.                         #
#                                                                             #
#              THIS SCRIPT IS ONLY FOR NON-MAGNETIC Re-BCO                    #
###############################################################################
#
# Conversion Factors (If Needed)
Ryd_eV=13.6057
Bohr_Ang=0.529

# Element Values & Notation
RE='Y'; RE_M='88.90585'
AE='Ba'; AE_M='137.327'
TM='Cu'; TM_M='63.546'
A='O'; A_M='15.994'
prefix=nm-$RE$AE$TM$A

###############################################################################
# Run-specific Input                                                          #
###############################################################################
elph_title='Calculate the electron-phonon coupling in '$prefix
elph_tr2_ph=1.0d-9
elph_prefix=$prefix
elph_fildvscf=$prefix'_dv'
#nq_size='1'

###############################################################################
# Housekeeping and Various Setup Stuff                                        #
###############################################################################
sysinfo=`uname '-a'`
kubuntu=`cat '/etc/issue'` 
now=`date`
cd `echo $0 | sed 's/\(.*\)\/.*/\1/'`
home_dir=`pwd`
cd ..
home_dir_up1=`pwd`
cd $home_dir

#pwscf_distro='espresso-3.2.3'
#pwscf_distro='espresso4.0cvs'
#pwscf_distro='O-sesame'
#pwscf_distro='espresso-4.0'
pwscf_distro='espresso-4.2.1'
phonon_exec='/home/pmpgrant/'$pwscf_distro'/PH/ph.x'

# cat to $prefix.elph.data file
printf "$0 \n" > $prefix.elph.data
cat >> $prefix.elph.data << EOF
  A PH script to calculate the electron-phonon coupling in $prefix
  Starting at $now
*******************************************************************************
System & OS Info
---------------------------------------------------------------------
  $sysinfo
  $kubuntu
*******************************************************************************
Element, Structure and Run Parameter Editable Options (!con cuidado!)
---------------------------------------------------------------------
  RE = $RE	AE = $AE	TM = $TM	A = $O
  RE_mass = $RE_M      AE_mass = $AE_M	     TM_mass = $TM_M      A_mass = $A_M

*******************************************************************************
Housekeeping
------------
  PWscf Distro = $pwscf_distro
  My Home      = $home_dir
EOF
#exit
###############################################################################
# Generate PH Run Stuff                                                       #
###############################################################################
cat > $prefix.elph.in << EOF
$elph_title
 &inputph
  recover=.false.,
  epsil=.false.,
  lraman=.false.,
  tr2_ph=$elph_tr2_ph,
  amass(1)=$RE_M,
  amass(2)=$AE_M,
  amass(3)=$TM_M,
  amass(4)=$A_M,
  prefix='$elph_prefix',
  fildvscf='$elph_fildvscf',
  fildyn='$prefix.dyn',
  outdir='$home_dir',
  elph=.true.,
  trans=.true.,
  ldisp=.false.,
 /
EOF
cat >> $prefix.elph.in << EOF
0 0 0
EOF
###############################################################################
# Do ELPH Run                                                                 #
###############################################################################
cat >> $prefix.elph.data << EOF
  Beginning $prefix electron-phonon calculation
  Starting at `date`
*******************************************************************************
$prefix.elph.in follows...
----------------------------------
EOF

cat >> $prefix.elph.data < $prefix.elph.in
cat >> $prefix.elph.data << EOF

*******************************************************************************
  Running $prefix ELPH...
EOF

# Exit Point for Testing
#exit

$phonon_exec < $prefix.elph.in | tee $prefix.elph.out

# Exit Point for Testing
#exit

cat >> $prefix.elph.data << EOF
  Finished...at `date`
  Collecting key data
  `grep 'kinetic-energy cut-off     ' $prefix.elph.out`
  `grep 'charge density cut-off     ' $prefix.elph.out`
  `grep 'convergence threshold     ' $prefix.elph.out`
  `grep 'beta               ' $prefix.elph.out`
  `grep 'number of iterations used ' $prefix.elph.out`
  `grep 'Exchange-correlation      ' $prefix.elph.out`
  `grep 'number of k points' $prefix.elph.out`
  `grep 'Fermi' $prefix.elph.out`
  `grep 'PHONON' $prefix.elph.out`


  Total CPU Time = `grep 'CPU time' $prefix.elph.out | cut -c 20-30`
  Total Wall Time = `grep 'wall time' $prefix.elph.out | cut -c 40-53`

EOF
exit

amass(1)=$RE_M,
  amass(2)=$AE_M,
  amass(3)=$TM_M,
  amass(4)=$A_M,
 lnscf=.false.,
nq1=$nq_size, nq2=$nq_size, nq3=$nq_size,